document.getElementById("Contents").innerHTML='\
    <ul><li><input type="checkbox" id="07"><label for="07">Makroer og programmering</label><ul>\
    <li><input type="checkbox" id="0701"><label for="0701">Generell informasjon og bruk av brukergrensesnittet</label><ul>\
    <li><a target="_top" href="nb/text/sbasic/shared/main0601.html">LibreOffice Basic Help</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/01000000.html">Programmering i LibreOffice Basic</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/00000002.html">Ordliste for LibreOffice</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/01010210.html">Grunnleggende</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/01020000.html">Syntaks</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/01050000.html">LibreOffice Basic IDE</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/01030100.html">IDE Overview</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/01030200.html">The Basic Editor</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/01050100.html">Watch Window</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/main0211.html">Macro Toolbar</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/05060700.html">Makro</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/vbasupport.html">Support for VBA Macros</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0702"><label for="0702">Kommandoer</label><ul>\
    <li><a target="_top" href="nb/text/sbasic/shared/01020300.html">Using Procedures and Functions</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/01020500.html">Libraries, Modules and Dialogs</a></li>\
    <li><input type="checkbox" id="070202"><label for="070202">Funksjoner, uttrykk og operatorer</label><ul>\
    <li><a target="_top" href="nb/text/sbasic/shared/03010000.html">Screen I/O Functions</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03020000.html">File I/O Functions</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03030000.html">Date and Time Functions</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03050000.html">Error-Handling Functions</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03060000.html">Logical Operators</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03070000.html">Mathematical Operators</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03080000.html">Numeric Functions</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03090000.html">Controlling Program Execution</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03100000.html">Variabler</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03040000.html">Basic Constants</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03110000.html">Sammenligningsoperatorer</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03120000.html">Streng</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/special_vba_func.html">Exclusive VBA functions</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03130000.html">Other Commands</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="070201"><label for="070201">Alfabetisk liste over funksjoner, uttrykk og operatorer</label><ul>\
    <li><a target="_top" href="nb/text/sbasic/shared/03080601.html">Abs Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03060100.html">AND Operator</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03104200.html">Array Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03120101.html">Asc Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03120111.html">AscW Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03080101.html">Atn Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03130100.html">Beep Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03010301.html">Blue Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03100100.html">CBool Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03120105.html">CByte Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03100050.html">CCur Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03030116.html">CDateFromUnoDateTime Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03030115.html">CDateToUnoDateTime Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03030114.html">CDateFromUnoTime Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03030113.html">CDateToUnoTime Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03030112.html">CDateFromUnoDate Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03030111.html">CDateToUnoDate Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03030108.html">CDateFromIso Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03030107.html">CDateToIso Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03100300.html">CDate Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03100400.html">CDbl Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03100060.html">CDec Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03100500.html">CInt Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03100600.html">CLng Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03100900.html">CSng Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03101000.html">CStr Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03090401.html">Call Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03020401.html">ChDir Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03020402.html">ChDrive Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03090402.html">Choose Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03120102.html">Chr Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03120112.html">ChrW Function [VBA]</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03020101.html">Close Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03110100.html">Comparison Operators</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03100700.html">Const Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03120313.html">ConvertFromURL Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03120312.html">ConvertToURL Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03080102.html">Cos Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03132400.html">CreateObject Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03131800.html">CreateUnoDialog Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03132000.html">CreateUnoListener Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03131600.html">CreateUnoService Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03131500.html">CreateUnoStruct Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03132300.html">CreateUnoValue Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03020403.html">CurDir Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03100070.html">CVar Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03100080.html">CVErr Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03030110.html">DateAdd Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03030120.html">DateDiff Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03030130.html">DatePart Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03030101.html">DateSerial Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03030102.html">DateValue Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03030301.html">Date Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03030103.html">Day Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03140000.html">DDB Function [VBA]</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03090403.html">Declare Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03101100.html">DefBool Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03101300.html">DefDate Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03101400.html">DefDbl Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03101500.html">DefInt Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03101600.html">DefLng Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03101700.html">DefObj Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03102000.html">DefVar Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03104300.html">DimArray Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03102100.html">Dim Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03020404.html">Dir Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03090201.html">Do...Loop Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03110100.html">Comparison Operators</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03090404.html">End Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03130800.html">Environ Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03020301.html">Eof Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03104600.html">EqualUnoObjects Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03060200.html">Eqv Operator</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03050100.html">Erl Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03050200.html">Err Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03050300.html">Error Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03050000.html">Error-Handling Functions</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03090412.html">Exit Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03080201.html">Exp Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03020405.html">FileAttr Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03020406.html">FileCopy Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03020407.html">FileDateTime Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03020415.html">FileExists Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03020408.html">FileLen Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03103800.html">FindObject Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03103900.html">FindPropertyObject Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03080501.html">Fix Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03090202.html">For...Next Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03120301.html">Format Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03150000.html">FormatDateTime Function [VBA]</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03020102.html">FreeFile Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03090405.html">FreeLibrary Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03090406.html">Function Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03090400.html">Further Statements</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03140001.html">FV Function [VBA]</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03080300.html">Generating Random Numbers</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03020409.html">GetAttr Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03132500.html">GetDefaultContext Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03132100.html">GetGuiType Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03131700.html">GetProcessServiceManager Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03131000.html">GetSolarVersion Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03130700.html">GetSystemTicks Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03020201.html">Get Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03131900.html">GlobalScope</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03090301.html">GoSub...Return Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03090302.html">GoTo Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03010302.html">Green Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03104400.html">HasUnoInterfaces Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03080801.html">Hex Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03030201.html">Hour Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03090103.html">IIf Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03090101.html">If...Then...Else Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03060300.html">Imp Operator</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03120401.html">InStr Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03120411.html">InStrRev Function [VBA]</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03160000.html">Input Function [VBA]</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03010201.html">InputBox Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03020202.html">Input# Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03080502.html">Int Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03140002.html">IPmt Function [VBA]</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03140003.html">IRR Function [VBA]</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03102200.html">IsArray Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03102300.html">IsDate Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03102400.html">IsEmpty Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03104000.html">IsMissing function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03102600.html">IsNull Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03102700.html">IsNumeric Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03102800.html">IsObject Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03104500.html">IsUnoStruct Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03120315.html">Join Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03020410.html">Kill Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03102900.html">LBound Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03120302.html">LCase Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03120304.html">LSet Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03120305.html">LTrim Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03120303.html">Left Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03120402.html">Len Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03103100.html">Let Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03020203.html">Line Input # Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03020302.html">Loc Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03020303.html">Lof Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03080202.html">Log Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03120306.html">Mid Function, Mid Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03030202.html">Minute Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03140004.html">MIRR Function [VBA]</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03020411.html">MkDir Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03070600.html">Mod Operator</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03030104.html">Month Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03150002.html">MonthName Function [VBA]</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03010102.html">MsgBox Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03010101.html">MsgBox Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03020412.html">Name Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03060400.html">Not Operator</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03030203.html">Now Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03140005.html">NPer Function [VBA]</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03140006.html">NPV Function [VBA]</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03080000.html">Numeric Functions</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03080802.html">Oct Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03050500.html">On Error GoTo ... Resume Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03090303.html">On...GoSub Statement; On...GoTo Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03020103.html">Open Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03103200.html">Option Base Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03103300.html">Option Explicit Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03103350.html">Option VBASupport Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03104100.html">Optional (in Function Statement)</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03060500.html">Or Operator</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03140007.html">Pmt Function [VBA]</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03140008.html">PPmt Function [VBA]</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03140009.html">PV Function [VBA]</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03010103.html">Print Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03103400.html">Public Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03020204.html">Put Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03010304.html">QBColor Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03140010.html">Rate Function [VBA]</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03010305.html">RGB Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03120308.html">RSet Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03120309.html">RTrim Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03080301.html">Randomize Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03102101.html">ReDim Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03010303.html">Red Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03090407.html">Rem Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03020104.html">Reset Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03120307.html">Right Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03020413.html">RmDir Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03080302.html">Rnd Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03170000.html">Round Function [VBA]</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03030204.html">Second Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03020304.html">Seek Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03020305.html">Seek Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03090102.html">Select...Case Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03020414.html">SetAttr Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03103700.html">Set Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03080701.html">Sgn Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03130500.html">Shell Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03080103.html">Sin Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03140011.html">SLN Function [VBA]</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03120201.html">Space Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03120314.html">Split Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03080401.html">Sqr Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03080400.html">Square Root Calculation</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03103500.html">Static Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03090408.html">Stop Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03120403.html">StrComp Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03120103.html">Str Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03120412.html">StrReverse Function [VBA]</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03120202.html">String Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03090409.html">Sub Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03090410.html">Switch Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03140012.html">SYD Function [VBA]</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03080104.html">Tan Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03030205.html">TimeSerial Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03030206.html">TimeValue Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03030302.html">Time Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03030303.html">Timer Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03080100.html">Trigonometiske funksjoner</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03120311.html">Trim Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03131300.html">TwipsPerPixelX Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03131400.html">TwipsPerPixelY Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03090413.html">Type Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03103600.html">TypeName Function; VarType Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03103000.html">UBound Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03120310.html">UCase Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03120104.html">Val Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03130600.html">Wait Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03030105.html">WeekDay Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03150001.html">WeekdayName Function [VBA]</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03090203.html">While...Wend Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03090411.html">With Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03020205.html">Write Statement</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03060600.html">XOR Operator</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03030106.html">Year Function</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03070100.html">"-" Operator</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03070200.html">"*" Operator</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03070300.html">"+" Operator</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03070400.html">"/" Operator</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03070500.html">"^" Operator</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="070205"><label for="070205">Avanserte Basic-bibliotek</label><ul>\
    <li><a target="_top" href="nb/text/sbasic/shared/03/lib_tools.html">Tools Library</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03/lib_depot.html">DEPOT Library</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03/lib_euro.html">EURO Library</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03/lib_formwizard.html">FORMWIZARD Library</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03/lib_gimmicks.html">GIMMICKS Library</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03/lib_schedule.html">SCHEDULE Library</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03/lib_script.html">SCRIPTBINDINGLIBRARY Library</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/03/lib_template.html">TEMPLATE Library</a></li>\
			</ul></li>\
                    </ul></li>\
    <li><input type="checkbox" id="0703"><label for="0703">Veiledninger</label><ul>\
    <li><a target="_top" href="nb/text/shared/guide/macro_recording.html">Ta opp en makro</a></li>\
    <li><a target="_top" href="nb/text/sbasic/guide/control_properties.html">Endring av egenskapene til kontrollelementer i dialogvinduredigeringa</a></li>\
    <li><a target="_top" href="nb/text/sbasic/guide/insert_control.html">Sette inn kontrollelementer i dialogvindu</a></li>\
    <li><a target="_top" href="nb/text/sbasic/guide/sample_code.html">Programmeringseksempler for kontrollelementer</a></li>\
    <li><a target="_top" href="nb/text/sbasic/guide/show_dialog.html">Åpne et dialogvindu med makrokode</a></li>\
    <li><a target="_top" href="nb/text/sbasic/guide/create_dialog.html">Lage et dialogvindu i Basic</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/01030400.html">Organizing Libraries and Modules</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/01020100.html">Bruk av Variabler</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/01020200.html">Using Objects</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/01030300.html">Debugging a Basic Program</a></li>\
    <li><a target="_top" href="nb/text/sbasic/shared/01040000.html">Event-Driven Macros</a></li>\
    <li><a target="_top" href="nb/text/sbasic/guide/access2base.html">Access2Base</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="08"><label for="08">Regneark</label><ul>\
    <li><input type="checkbox" id="0801"><label for="0801">Generell informasjon og bruk av brukergrensesnittet</label><ul>\
    <li><a target="_top" href="nb/text/scalc/main0000.html">Velkommen til hjelp for LibreOffice Calc</a></li>\
    <li><a target="_top" href="nb/text/scalc/main0503.html">LibreOffice Calc-funksjoner</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/keyboard.html">Hurtigtaster (tilgjengelighet i LibreOffice Calc)</a></li>\
    <li><a target="_top" href="nb/text/scalc/04/01020000.html">Hurtigtaster for regneark</a></li>\
    <li><a target="_top" href="nb/text/scalc/05/02140000.html">Feilkoder i LibreOffice Calc</a></li>\
    <li><a target="_top" href="nb/text/scalc/01/04060112.html">Add-in for Programming in LibreOffice Calc</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/main.html">Hjelp til bruk av LibreOffice Calc</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0802"><label for="0802">Kommando og menyreferanse</label><ul>\
    <li><input type="checkbox" id="080201"><label for="080201">Menyer</label><ul>\
    <li><a target="_top" href="nb/text/scalc/main0100.html">Menyer</a></li>\
    <li><a target="_top" href="nb/text/scalc/main0101.html">Fil</a></li>\
    <li><a target="_top" href="nb/text/scalc/main0102.html">Rediger</a></li>\
    <li><a target="_top" href="nb/text/scalc/main0103.html">Vis</a></li>\
    <li><a target="_top" href="nb/text/scalc/main0104.html">Sett inn</a></li>\
    <li><a target="_top" href="nb/text/scalc/main0105.html">Format</a></li>\
    <li><a target="_top" href="nb/text/scalc/main0116.html">Ark</a></li>\
    <li><a target="_top" href="nb/text/scalc/main0112.html">Data</a></li>\
    <li><a target="_top" href="nb/text/scalc/main0106.html">Verktøy</a></li>\
    <li><a target="_top" href="nb/text/scalc/main0107.html">Vindu</a></li>\
    <li><a target="_top" href="nb/text/shared/main0108.html">Hjelp</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="080202"><label for="080202">Verktøylinjer</label><ul>\
    <li><a target="_top" href="nb/text/scalc/main0200.html">Verktøylinjer</a></li>\
    <li><a target="_top" href="nb/text/scalc/main0202.html">Formateringslinja</a></li>\
    <li><a target="_top" href="nb/text/scalc/main0203.html">Linja Egenskaper for tegneobjekter</a></li>\
    <li><a target="_top" href="nb/text/scalc/main0205.html">Tekstformateringslinja</a></li>\
    <li><a target="_top" href="nb/text/scalc/main0206.html">Formellinja</a></li>\
    <li><a target="_top" href="nb/text/scalc/main0208.html">Statuslinja</a></li>\
    <li><a target="_top" href="nb/text/scalc/main0210.html">Linje for forhåndsvisning</a></li>\
    <li><a target="_top" href="nb/text/scalc/main0214.html">Bildelinje</a></li>\
    <li><a target="_top" href="nb/text/scalc/main0218.html">Verktøylinja</a></li>\
    <li><a target="_top" href="nb/text/shared/main0201.html">Standardlinja</a></li>\
    <li><a target="_top" href="nb/text/shared/main0212.html">Tabelldatalinja</a></li>\
    <li><a target="_top" href="nb/text/shared/main0213.html">Navigasjonslinje for skjema</a></li>\
    <li><a target="_top" href="nb/text/shared/main0214.html">Verktøylinje for spørringsutforming</a></li>\
    <li><a target="_top" href="nb/text/shared/main0226.html">Verktøylinje for skjemautforming</a></li>\
			</ul></li>\
		</ul></li>\
    <li><input type="checkbox" id="0803"><label for="0803">Funksjonstyper og operatorer</label><ul>\
    <li><a target="_top" href="nb/text/scalc/01/04060000.html">Funksjonsveiviser</a></li>\
    <li><a target="_top" href="nb/text/scalc/01/04060100.html">Funksjon etter kategori</a></li>\
    <li><a target="_top" href="nb/text/scalc/01/04060107.html">Matrisefunksjoner</a></li>\
    <li><a target="_top" href="nb/text/scalc/01/04060120.html">Bit Operation Functions</a></li>\
    <li><a target="_top" href="nb/text/scalc/01/04060101.html">Databasefunksjoner</a></li>\
    <li><a target="_top" href="nb/text/scalc/01/04060102.html">Dato- og klokkeslettsfunksjoner</a></li>\
    <li><a target="_top" href="nb/text/scalc/01/04060103.html">Finansfunksjoner del en</a></li>\
    <li><a target="_top" href="nb/text/scalc/01/04060119.html">Finansfunksjoner del en</a></li>\
    <li><a target="_top" href="nb/text/scalc/01/04060118.html">Finansfunksjoner del en</a></li>\
    <li><a target="_top" href="nb/text/scalc/01/04060104.html">Informasjonsfunksjoner</a></li>\
    <li><a target="_top" href="nb/text/scalc/01/04060105.html">Logiske funksjoner</a></li>\
    <li><a target="_top" href="nb/text/scalc/01/04060106.html">Matematiske funksjoner</a></li>\
    <li><a target="_top" href="nb/text/scalc/01/04060108.html">Statistikkfunksjoner</a></li>\
    <li><a target="_top" href="nb/text/scalc/01/04060181.html">Finansfunksjoner del en</a></li>\
    <li><a target="_top" href="nb/text/scalc/01/04060182.html">Finansfunksjoner del en</a></li>\
    <li><a target="_top" href="nb/text/scalc/01/04060183.html">Finansfunksjoner del en</a></li>\
    <li><a target="_top" href="nb/text/scalc/01/04060184.html">Finansfunksjoner del en</a></li>\
    <li><a target="_top" href="nb/text/scalc/01/04060185.html">Finansfunksjoner del en</a></li>\
    <li><a target="_top" href="nb/text/scalc/01/04060109.html">Regnearksfunksjoner</a></li>\
    <li><a target="_top" href="nb/text/scalc/01/04060110.html">Tekstfunksjoner</a></li>\
    <li><a target="_top" href="nb/text/scalc/01/04060111.html">Tilleggsfunksjoner</a></li>\
    <li><a target="_top" href="nb/text/scalc/01/04060115.html">Add-in Functions, List of Analysis Functions Part One</a></li>\
    <li><a target="_top" href="nb/text/scalc/01/04060116.html">Add-in Functions, List of Analysis Functions Part Two</a></li>\
    <li><a target="_top" href="nb/text/scalc/01/04060199.html">Operators in LibreOffice Calc</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/userdefined_function.html">Selvlagde funksjoner</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0804"><label for="0804">Åpne, lagre, import og eksport</label><ul>\
    <li><a target="_top" href="nb/text/scalc/guide/webquery.html">Sette inn eksterne data i tabeller (nettspørringer)</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/html_doc.html">Lagre og åpne ark i HTML</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/csv_formula.html">Importere og eksportere tekstfiler</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0805"><label for="0805">Formatering</label><ul>\
    <li><a target="_top" href="nb/text/scalc/guide/text_rotate.html">Rotere tekst</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/text_wrap.html">Skrive tekst med flere linjer</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/text_numbers.html">Formatere tall som tekst</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/super_subscript.html">Hevet/senket skrift</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/row_height.html">Endre radhøyde eller kolonnebredde</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/cellstyle_conditional.html">Bruke vilkårsformatering</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/cellstyle_minusvalue.html">Utheve negative tall</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/cellstyle_by_formula.html">Angi format med formler</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/integer_leading_zero.html">Skrive inn tall med innledende nuller</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/format_table.html">Formatere regneark</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/format_value.html">Formatere tall med desimaler</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/value_with_name.html">Navngi celler</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/table_rotate.html">Rotere tabeller (omstille)</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/rename_table.html">Gi nytt navn til ark</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/year2000.html">19xx/20xx-år</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/rounding_numbers.html">Bruke avrundede tall</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/currency_format.html">Celler i valutaformat</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/autoformat.html">Bruke autoformatering på tabeller</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/note_insert.html">Inserting and Editing Comments</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/design.html">Velge temaer for ark</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/fraction_enter.html">Skrive inn brøker</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0806"><label for="0806">Filtrering og sortering</label><ul>\
    <li><a target="_top" href="nb/text/scalc/guide/filters.html">Bruke filtre</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/specialfilter.html">Filtre: Bruke avanserte filtre</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/autofilter.html">Bruke autofiltrering</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/sorted_list.html">Bruke sorteringslister</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0807"><label for="0807">Utskrift</label><ul>\
    <li><a target="_top" href="nb/text/scalc/guide/print_title_row.html">Skrive ut rader eller kolonner på hver side</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/print_landscape.html">Skrive ut regneark liggende</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/print_details.html">Skrive ut regneark</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/print_exact.html">Angi antall sider som skal skrives ut</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0808"><label for="0808">Dataområder</label><ul>\
    <li><a target="_top" href="nb/text/scalc/guide/database_define.html">Angi databaseområder</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/database_filter.html">Filtrere celleområder</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/database_sort.html">Sortere data</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0809"><label for="0809">Pivottabell</label><ul>\
    <li><a target="_top" href="nb/text/scalc/guide/datapilot.html">Pivottabell</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/datapilot_createtable.html">Lage dataveivisertabeller</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/datapilot_deletetable.html">Slette dataveivisertabeller</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/datapilot_edittable.html">Endre dataveivisertabeller</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/datapilot_filtertable.html">Filtrere dataveivisertabeller</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/datapilot_tipps.html">Selecting Pivot Table Output Ranges</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/datapilot_updatetable.html">Oppdatere dataveivisertabeller</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="08091"><label for="08091">Pivotdiagram</label><ul>\
    <li><a target="_top" href="nb/text/scalc/guide/pivotchart.html">Pivot Chart</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/pivotchart_create.html">Creating Pivot Charts</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/pivotchart_edit.html">Editing Pivot Charts</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/pivotchart_filter.html">Filtering Pivot Charts</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/pivotchart_update.html">Pivot Chart Update</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/pivotchart_delete.html">Deleting Pivot Charts</a></li>\
                </ul></li>\
    <li><input type="checkbox" id="0810"><label for="0810">Scenarier</label><ul>\
    <li><a target="_top" href="nb/text/scalc/guide/scenario.html">Bruke scenarier</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0811"><label for="0811">Åpne, lagre, import og eksport</label><ul>\
    <li><a target="_top" href="nb/text/scalc/guide/relativ_absolut_ref.html">Adresser og referanser, absolutte og relative</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/cellreferences.html">Referere til en celle i et annet dokument</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/cellreferences_url.html">Referere til andre ark og referere med nettadresser</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/cellreference_dragdrop.html">Referere til celler ved å dra og slippe</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/address_auto.html">Bruke navn som adresser</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0812"><label for="0812">Innlasting, lagring, importering, eksportering</label><ul>\
    <li><a target="_top" href="nb/text/scalc/guide/table_view.html">Endre tabellvisning</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/formula_value.html">Vise formler eller verdier</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/line_fix.html">Fryse rader eller kolonner som overskrifter</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/multi_tables.html">Navigere gjennom fanene til ark</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/edit_multitables.html">Kopiere til flere ark</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/cellcopy.html">Bare kopier synlige celler</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/mark_cells.html">Velge flere celler</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0813"><label for="0813">Formler og beregninger</label><ul>\
    <li><a target="_top" href="nb/text/scalc/guide/formulas.html">Beregne med formler</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/formula_copy.html">Kopiere formler</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/formula_enter.html">Skrive inn formler</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/formula_value.html">Vise formler eller verdier</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/calculate.html">Beregne i regneark</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/calc_date.html">Beregninger med datoer og klokkeslett</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/calc_series.html">Beregne serier automatisk</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/calc_timevalues.html">Beregne tidsforskjeller</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/matrixformula.html">Skrive inn matriseformler</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0814"><label for="0814">Beskyttelse</label><ul>\
    <li><a target="_top" href="nb/text/scalc/guide/cell_protect.html">Beskytte celler mot endring</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/cell_unprotect.html">Slå av beskyttelse av celler</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0815"><label for="0815">Forskjellig</label><ul>\
    <li><a target="_top" href="nb/text/scalc/guide/auto_off.html">Slå av automatiske endringer</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/consolidate.html">Slå sammen data</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/goalseek.html">Tilpasse verdier</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/multioperation.html">Utføre flere operasjoner</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/multitables.html">Bruke flere ark</a></li>\
    <li><a target="_top" href="nb/text/scalc/guide/validity.html">Gyldigheten til celleinnhold</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="05"><label for="05">Grafer og diagrammer</label><ul>\
    <li><input type="checkbox" id="0501"><label for="0501">Generell informasjon</label><ul>\
    <li><a target="_top" href="nb/text/schart/main0000.html">Diagrammer i LibreOffice</a></li>\
    <li><a target="_top" href="nb/text/schart/main0503.html">LibreOffice Chart-funksjoner</a></li>\
    <li><a target="_top" href="nb/text/schart/04/01020000.html">Hurtigtaster for diagrammer</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="01"><label for="01">Installasjon</label><ul>\
    <li><a target="_top" href="nb/text/shared/guide/ms_doctypes.html">Endre filtilknytning for Microsoft Office-dokumenttyper</a></li>\
    <li><a target="_top" href="nb/text/shared/01/profile_safe_mode.html">Safe Mode</a></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="10"><label for="10">Fellesemner i hjelpefunksjonen</label><ul>\
    <li><input type="checkbox" id="1001"><label for="1001">Generell informasjon</label><ul>\
    <li><a target="_top" href="nb/text/shared/main0400.html">Hurtigtaster</a></li>\
    <li><a target="_top" href="nb/text/shared/00/00000005.html">Generell ordliste</a></li>\
    <li><a target="_top" href="nb/text/shared/00/00000002.html">Ordliste over Internett-uttrykk</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/accessibility.html">Tilgjengelighet i LibreOffice</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/keyboard.html">Hurtigtaster i (LibreOffice Tilgjengelighet)</a></li>\
    <li><a target="_top" href="nb/text/shared/04/01010000.html">Generelle hurtigtaster i LibreOffice</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/version_number.html">Versjoner og utgivelsesnummere</a></li>\
</ul></li>\
    <li><input type="checkbox" id="1002"><label for="1002">LibreOffice og Microsoft Office</label><ul>\
    <li><a target="_top" href="nb/text/shared/guide/ms_user.html">Bruke Microsoft Office og LibreOffice</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/microsoft_terms.html">Sammenligning av ledd i Microsoft Office og LibreOffice</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/ms_import_export_limitations.html">Om konvertering av Microsoft Office-dokumenter</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/ms_doctypes.html">Endre filtilknytning for Microsoft Office-dokumenttyper</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1004"><label for="1004">Alternativer i LibreOffice</label><ul>\
    <li><a target="_top" href="nb/text/shared/optionen/01000000.html">Innstillinger</a></li>\
    <li><a target="_top" href="nb/text/shared/optionen/01010100.html">Brukerinformasjon</a></li>\
    <li><a target="_top" href="nb/text/shared/optionen/01010200.html">Generelt</a></li>\
    <li><a target="_top" href="nb/text/shared/optionen/01010300.html">Stier</a></li>\
    <li><a target="_top" href="nb/text/shared/optionen/01010400.html">Skrivestøtte</a></li>\
    <li><a target="_top" href="nb/text/shared/optionen/01010500.html">Farge</a></li>\
    <li><a target="_top" href="nb/text/shared/optionen/01010600.html">Generelt</a></li>\
    <li><a target="_top" href="nb/text/shared/optionen/01010700.html">Skrifter</a></li>\
    <li><a target="_top" href="nb/text/shared/optionen/01010800.html">Vis</a></li>\
    <li><a target="_top" href="nb/text/shared/optionen/01010900.html">Utskriftsinnstillinger</a></li>\
    <li><a target="_top" href="nb/text/shared/optionen/01012000.html">Programfarger</a></li>\
    <li><a target="_top" href="nb/text/shared/optionen/01013000.html">Tilgjengelighet</a></li>\
    <li><a target="_top" href="nb/text/shared/optionen/java.html">Advanced</a></li>\
    <li><a target="_top" href="nb/text/shared/optionen/expertconfig.html">Expert Configuration</a></li>\
    <li><a target="_top" href="nb/text/shared/optionen/persona_firefox.html">Personalization</a></li>\
    <li><a target="_top" href="nb/text/shared/optionen/BasicIDE.html">Basic IDE</a></li>\
    <li><a target="_top" href="nb/text/shared/optionen/opencl.html">Open CL</a></li>\
    <li><a target="_top" href="nb/text/shared/optionen/01020000.html">Alternativer for Last inn / Lagre</a></li>\
    <li><a target="_top" href="nb/text/shared/optionen/01030000.html">Alternativer for Internett</a></li>\
    <li><a target="_top" href="nb/text/shared/optionen/01040000.html">Alternativer for tekstdokumenter</a></li>\
    <li><a target="_top" href="nb/text/shared/optionen/01050000.html">Innstillinger for HTML-dokumenter</a></li>\
    <li><a target="_top" href="nb/text/shared/optionen/01060000.html">Innstillinger for regneark</a></li>\
    <li><a target="_top" href="nb/text/shared/optionen/01070000.html">Presentasjonsinnstillinger</a></li>\
    <li><a target="_top" href="nb/text/shared/optionen/01080000.html">Innstillinger for tegninger</a></li>\
    <li><a target="_top" href="nb/text/shared/optionen/01090000.html">Formel</a></li>\
    <li><a target="_top" href="nb/text/shared/optionen/01110000.html">Innstillinger for diagrammer</a></li>\
    <li><a target="_top" href="nb/text/shared/optionen/01130100.html">VBA-egenskaper</a></li>\
    <li><a target="_top" href="nb/text/shared/optionen/01130200.html">Microsoft Office</a></li>\
    <li><a target="_top" href="nb/text/shared/optionen/01140000.html">Språk</a></li>\
    <li><a target="_top" href="nb/text/shared/optionen/01150000.html">Alternativer for språkinnstillinger</a></li>\
    <li><a target="_top" href="nb/text/shared/optionen/01160000.html">Innstillinger for datakilder</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1005"><label for="1005">Veivisere</label><ul>\
    <li><a target="_top" href="nb/text/shared/autopi/01000000.html">Veiviser</a></li>\
    <li><input type="checkbox" id="100501"><label for="100501">Brevveiviseren</label><ul>\
    <li><a target="_top" href="nb/text/shared/autopi/01010000.html">Brevveiviseren</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="100502"><label for="100502">Faksveiviser</label><ul>\
    <li><a target="_top" href="nb/text/shared/autopi/01020000.html">Faksveiviseren</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="100504"><label for="100504">Møteplanveiviser</label><ul>\
    <li><a target="_top" href="nb/text/shared/autopi/01040000.html">Møteplanveiviseren</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="100506"><label for="100506">Veiviser for HTML-eksport</label><ul>\
    <li><a target="_top" href="nb/text/shared/autopi/01110000.html">HTML-eksport</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="100510"><label for="100510">Veiviser for dokumentkonvertering</label><ul>\
    <li><a target="_top" href="nb/text/shared/autopi/01130000.html">Dokumentkonvertering</a></li>\
			</ul></li>\
    <li><a target="_top" href="nb/text/shared/autopi/01150000.html">Veiviseren Euro-omregner</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1006"><label for="1006">Oppsett av LibreOffice</label><ul>\
    <li><a target="_top" href="nb/text/shared/guide/configure_overview.html">Sette opp LibreOffice</a></li>\
    <li><a target="_top" href="nb/text/shared/01/packagemanager.html">Utvidelser</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/flat_icons.html">Forandre ikonvisninger</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/edit_symbolbar.html">Legge til knapper på verktøylinjer</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/workfolder.html">Endre arbeidsmappe</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/standard_template.html">Endre standardmaler</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/data_addressbook.html">Registrere en adressebok</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/formfields.html">Sette inn og redigere knapper</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1007"><label for="1007">Arbeide med brukergrensesnittet</label><ul>\
    <li><a target="_top" href="nb/text/shared/guide/navigator_setcursor.html">Bruke Dokumentstruktur for å komme raskt til objekter</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/navigator.html">Dokumentstruktur</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/autohide.html">Vise, feste og skjule vinduer</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/navpane_on.html">Vise navigasjonspanelet i Hjelp</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/textmode_change.html">Bytte mellom innsettingstilstand og overskrivingstilstand</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/floating_toolbar.html">Bruke verktøylinjer</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="10071"><label for="10071">Digitale signaturer</label><ul>\
    <li><a target="_top" href="nb/text/shared/guide/digital_signatures.html">Om digitale signaturer</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/digitalsign_send.html">Legge til digitale signaturer</a></li>\
    <li><a target="_top" href="nb/text/shared/01/digitalsignaturespdf.html">Digital Signature in PDF Export</a></li>\
    <li><a target="_top" href="nb/text/shared/01/signexistingpdf.html">Signing Existing PDF</a></li>\
    <li><a target="_top" href="nb/text/swriter/01/addsignatureline.html">Adding Signature Line in Text Documents</a></li>\
    <li><a target="_top" href="nb/text/swriter/01/signsignatureline.html">Signing the Signature Line</a></li>\
                </ul></li>\
    <li><input type="checkbox" id="1008"><label for="1008">Utskrift, faks, sending</label><ul>\
    <li><a target="_top" href="nb/text/shared/guide/labels_database.html">Skrive ut adresseetiketter</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/print_blackwhite.html">Skrive ut i svart-hvitt</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/email.html">Sende dokumenter som e-postvedlegg</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/fax.html">Sende fakser og sette opp LibreOffice for faksing</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1009"><label for="1009">Dra og slipp</label><ul>\
    <li><a target="_top" href="nb/text/shared/guide/dragdrop.html">Dra og slippe i et LibreOffice-dokument</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/dragdroptext.html">Flytte og kopiere tekst i dokumenter</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/dragdrop_table.html">Kopiere regnearksområder til tekstdokumenter</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/dragdrop_graphic.html">Kopiere bilder mellom dokumenter</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/dragdrop_fromgallery.html">Kopiere bilder fra galleriet</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/dragdrop_beamer.html">Dra og slippe i datakildevisningen</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1010"><label for="1010">Kopiering og innliming</label><ul>\
    <li><a target="_top" href="nb/text/shared/guide/copy_drawfunctions.html">Kopiere tegneobjekter til andre dokumenter</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/dragdrop_graphic.html">Kopiere bilder mellom dokumenter</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/dragdrop_fromgallery.html">Kopiere bilder fra galleriet</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/dragdrop_table.html">Kopiere regnearksområder til tekstdokumenter</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1012"><label for="1012">Grafer og diagrammer</label><ul>\
    <li><a target="_top" href="nb/text/shared/guide/chart_insert.html">Sette inn diagrammer</a></li>\
    <li><a target="_top" href="nb/text/schart/main0000.html">Diagrammer i LibreOffice</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1013"><label for="1013">Åpne, lagre, import og eksport</label><ul>\
    <li><a target="_top" href="nb/text/shared/guide/doc_open.html">Åpne dokumenter</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/import_ms.html">Åpne dokumenter som er lagret i andre formater</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/doc_save.html">Lagre dokumenter</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/doc_autosave.html">Lagre dokumenter automatisk</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/export_ms.html">Lagre dokumenter i andre formater</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/data_dbase2office.html">Importere og eksportere data i tekstformat</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1014"><label for="1014">Lenker og referanser</label><ul>\
    <li><a target="_top" href="nb/text/shared/guide/hyperlink_insert.html">Sette inn hyperlenker</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/hyperlink_rel_abs.html">Relative og absolutte lenker</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/hyperlink_edit.html">Redigere hyperlenker</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1015"><label for="1015">Sporing av dokumentversjoner</label><ul>\
    <li><a target="_top" href="nb/text/shared/guide/redlining_doccompare.html">Sammenligne versjoner av et dokument</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/redlining_docmerge.html">Flette versjoner</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/redlining_enter.html">Registrere endringer</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/redlining.html">Registrere og vise endringer</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/redlining_accept.html">Godta eller avvise endringer</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/redlining_versions.html">Versjonsbehandling</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1016"><label for="1016">Etiketter og visittkort</label><ul>\
    <li><a target="_top" href="nb/text/shared/guide/labels.html">Lage og skrive ut etiketter og visittkort</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1018"><label for="1018">Innsetting av eksterne data</label><ul>\
    <li><a target="_top" href="nb/text/shared/guide/copytable2application.html">Sette inn data fra regneark</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/copytext2application.html">Sette inn data fra tekstdokumenter</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/insert_bitmap.html">Sette inn, redigere og lagre punktbilder</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/dragdrop_gallery.html">Legge til bilder i galleriet</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1019"><label for="1019">Automatiske funksjoner</label><ul>\
    <li><a target="_top" href="nb/text/shared/guide/autocorr_url.html">Slå av automatisk URL-gjenkjenning</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1020"><label for="1020">Søk og erstatt</label><ul>\
    <li><a target="_top" href="nb/text/shared/guide/data_search2.html">Søke med et skjemarfilter</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/data_search.html">Søking i tabeller og skjemadokumenter</a></li>\
    <li><a target="_top" href="nb/text/shared/01/02100001.html">Liste over regulære uttrykk</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1021"><label for="1021">Veiledninger</label><ul>\
    <li><a target="_top" href="nb/text/shared/guide/linestyles.html">Bruke linjestiler</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/text_color.html">Endre tekstfargen</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/change_title.html">Endre tittelen til et dokument</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/round_corner.html">Lage avrundede hjørner</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/background.html">Angi bakgrunnsfarger bakgrunnbilder</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/lineend_define.html">Angi linjeslutter</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/linestyle_define.html">Angi linjestiler</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/insert_graphic_drawit.html">Redigere bildeobjekter</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/line_intext.html">Tegne linjer i tekst</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/aaa_start.html">De første stegene</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/gallery_insert.html">Sette inn objekter fra galleriet</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/space_hyphen.html">Inserting Non-breaking Spaces, Hyphens and Soft Hyphens</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/insert_specialchar.html">Sette inn spesialtegn</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/tabs.html">Sette inn og redigere tabulatorstopp</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/protection.html">Beskytte innhold i LibreOffice</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/redlining_protect.html">Beskytte poster</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/pageformat_max.html">Angi det største utskriftsområdet på en side</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/measurement_units.html">Velge måleenheter</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/language_select.html">Velge språk for dokumentet</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/data_tabledefine.html">Tabellutforming</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/numbering_stop.html">Slå av punktmerking og nummerering i enkelte avsnitt</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="09"><label for="09">Databasefunksjoner</label><ul>\
    <li><input type="checkbox" id="0901"><label for="0901">Generell informasjon</label><ul>\
    <li><a target="_top" href="nb/text/shared/explorer/database/main.html">LibreOffice Database</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/database_main.html">Databaseoversikt</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/data_new.html">Lage en ny database</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/data_tables.html">Arbeide med tabeller</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/data_queries.html">Arbeide med spørringer</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/data_forms.html">Arbeide med skjemaer</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/data_reports.html">Lage rapporter</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/data_register.html">Registrere og slette en database</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/data_im_export.html">Importere og eksportere data i Base</a></li>\
    <li><a target="_top" href="nb/text/shared/guide/data_enter_sql.html">Utføre SQL-kommandoer</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="04"><label for="04">Presentasjoner og tegninger</label><ul>\
    <li><input type="checkbox" id="0401"><label for="0401">Generell informasjon og bruk av brukergrensesnittet</label><ul>\
    <li><a target="_top" href="nb/text/simpress/main0000.html">Velkommen til hjelp for LibreOffice Impress</a></li>\
    <li><a target="_top" href="nb/text/sdraw/main0000.html">Velkommen til hjelp for LibreOffice Draw</a></li>\
    <li><a target="_top" href="nb/text/simpress/main0503.html">Funksjoner i LibreOffice Impress</a></li>\
    <li><a target="_top" href="nb/text/sdraw/main0503.html">Funksjoner i LibreOffice Draw</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/keyboard.html">Bruk av hurtigtaster i LibreOffice Impress</a></li>\
    <li><a target="_top" href="nb/text/sdraw/guide/keyboard.html">Hurtigtaster for tegneobjekter</a></li>\
    <li><a target="_top" href="nb/text/simpress/04/01020000.html">Hurtigtaster for LibreOffice Impress</a></li>\
    <li><a target="_top" href="nb/text/simpress/04/presenter.html">Vis tastaursnarveier i presentasjonskonsollen</a></li>\
    <li><a target="_top" href="nb/text/sdraw/04/01020000.html">Hurtigtaster for tegninger</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/main.html">Instruksjoner for bruk av LibreOffice Impress</a></li>\
    <li><a target="_top" href="nb/text/sdraw/guide/main.html">Hjelp til bruk av LibreOffice Draw</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0402"><label for="0402">Kommando og menyreferanse</label><ul>\
    <li><input type="checkbox" id="040201"><label for="040201">Presentasjoner (LibreOffice Impress)</label><ul>\
    <li><input type="checkbox" id="04020101"><label for="04020101">Menyer</label><ul>\
    <li><a target="_top" href="nb/text/simpress/main0100.html">Menyer</a></li>\
    <li><a target="_top" href="nb/text/simpress/main0101.html">Fil</a></li>\
    <li><a target="_top" href="nb/text/simpress/main0102.html">Rediger</a></li>\
    <li><a target="_top" href="nb/text/simpress/main0103.html">Vis</a></li>\
    <li><a target="_top" href="nb/text/simpress/main0104.html">Sett inn</a></li>\
    <li><a target="_top" href="nb/text/simpress/main0105.html">Format</a></li>\
    <li><a target="_top" href="nb/text/simpress/main0117.html">Lysbilde</a></li>\
    <li><a target="_top" href="nb/text/simpress/main0114.html">Lysbildeframvisning</a></li>\
    <li><a target="_top" href="nb/text/simpress/main0106.html">Verktøy</a></li>\
    <li><a target="_top" href="nb/text/simpress/main0107.html">Vindu</a></li>\
    <li><a target="_top" href="nb/text/shared/main0108.html">Hjelp</a></li>\
                 </ul></li>\
    <li><input type="checkbox" id="04020102"><label for="04020102">Verktøylinjer</label><ul>\
    <li><a target="_top" href="nb/text/simpress/main0200.html">Verktøylinjer</a></li>\
    <li><a target="_top" href="nb/text/simpress/main0202.html">Verktøylinja for linje og fyll</a></li>\
    <li><a target="_top" href="nb/text/simpress/main0203.html">Tekstformateringslinja</a></li>\
    <li><a target="_top" href="nb/text/simpress/main0204.html">Verktøylinja for lysbildevisning</a></li>\
    <li><a target="_top" href="nb/text/simpress/main0206.html">Statuslinja</a></li>\
    <li><a target="_top" href="nb/text/simpress/main0209.html">Linjaler</a></li>\
    <li><a target="_top" href="nb/text/simpress/main0210.html">Tegnelinja</a></li>\
    <li><a target="_top" href="nb/text/simpress/main0211.html">Disposisjonslinja</a></li>\
    <li><a target="_top" href="nb/text/simpress/main0212.html">Lysbildesorteringslinja</a></li>\
    <li><a target="_top" href="nb/text/simpress/main0213.html">Innstillinger-linja</a></li>\
    <li><a target="_top" href="nb/text/simpress/main0214.html">Bildelinje</a></li>\
    <li><a target="_top" href="nb/text/shared/main0201.html">Standardlinja</a></li>\
    <li><a target="_top" href="nb/text/shared/main0213.html">Navigasjonslinje for skjema</a></li>\
    <li><a target="_top" href="nb/text/shared/main0226.html">Verktøylinje for skjemautforming</a></li>\
    <li><a target="_top" href="nb/text/shared/main0227.html">Punktredigeringslinja</a></li>\
                 </ul></li>\
             </ul></li>\
    <li><input type="checkbox" id="040202"><label for="040202">Tegninger (LibreOffice Draw)</label><ul>\
    <li><input type="checkbox" id="04020201"><label for="04020201">Menyer</label><ul>\
    <li><a target="_top" href="nb/text/sdraw/main0100.html">Menyer</a></li>\
    <li><a target="_top" href="nb/text/sdraw/main0101.html">Fil</a></li>\
    <li><a target="_top" href="nb/text/sdraw/main0102.html">Rediger</a></li>\
    <li><a target="_top" href="nb/text/sdraw/main0103.html">Vis</a></li>\
    <li><a target="_top" href="nb/text/sdraw/main0104.html">Sett inn</a></li>\
    <li><a target="_top" href="nb/text/sdraw/main0105.html">Format</a></li>\
    <li><a target="_top" href="nb/text/sdraw/main0106.html">Verktøy</a></li>\
    <li><a target="_top" href="nb/text/simpress/main0113.html">Endre</a></li>\
    <li><a target="_top" href="nb/text/simpress/main0107.html">Vindu</a></li>\
    <li><a target="_top" href="nb/text/shared/main0108.html">Hjelp</a></li>\
                 </ul></li>\
    <li><input type="checkbox" id="04020202"><label for="04020202">Verktøylinjer</label><ul>\
    <li><a target="_top" href="nb/text/sdraw/main0200.html">Verktøylinjer</a></li>\
    <li><a target="_top" href="nb/text/sdraw/main0210.html">Tegnelinja</a></li>\
    <li><a target="_top" href="nb/text/sdraw/main0213.html">Innstillingslinja</a></li>\
    <li><a target="_top" href="nb/text/shared/main0201.html">Standardlinja</a></li>\
    <li><a target="_top" href="nb/text/shared/main0213.html">Navigasjonslinje for skjema</a></li>\
    <li><a target="_top" href="nb/text/shared/main0226.html">Verktøylinje for skjemautforming</a></li>\
    <li><a target="_top" href="nb/text/shared/main0227.html">Punktredigeringslinja</a></li>\
                 </ul></li>\
             </ul></li>\
         </ul></li>\
    <li><input type="checkbox" id="0403"><label for="0403">Åpne, lagre, import og eksport</label><ul>\
    <li><a target="_top" href="nb/text/simpress/guide/html_export.html">Lagre en presentasjon i HTML-format</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/html_import.html">Importer HTML-sider inn i presentasjoner</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/palette_files.html">Lasting av farge-, fargeovergang- og skraveringslister</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/animated_gif_save.html">Eksportere animasjoner i GIF-format</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/table_insert.html">Sette inn regneark i lysbilder</a></li>\
    <li><a target="_top" href="nb/text/sdraw/guide/graphic_insert.html">Sette inn bilder</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/page_copy.html">Kopiering av lysbilder fra andre presentasjoner</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0404"><label for="0404">Formatering</label><ul>\
    <li><a target="_top" href="nb/text/simpress/guide/palette_files.html">Lasting av farge-, fargeovergang- og skraveringslister</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/line_arrow_styles.html">Henting av linje- og pilstiler</a></li>\
    <li><a target="_top" href="nb/text/sdraw/guide/color_define.html">Bland egne farger</a></li>\
    <li><a target="_top" href="nb/text/sdraw/guide/gradient.html">Lage fargeovergangsfyll</a></li>\
    <li><a target="_top" href="nb/text/sdraw/guide/eyedropper.html">Erstatte farger</a></li>\
    <li><a target="_top" href="nb/text/sdraw/guide/align_arrange.html">Stille opp, justere og fordele objekter</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/background.html">Endring av bakgrunn for lysbildet</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/footer.html">Legg en topptekst eller bunntekst til alle lysbilder</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/masterpage.html">Bruk et lysbildeoppsett på et hovedlysbilde</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/move_object.html">Flytting av objekter</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0405"><label for="0405">Utskrift</label><ul>\
    <li><a target="_top" href="nb/text/simpress/guide/printing.html">Utskrift av presentasjoner</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/print_tofit.html">Utskrift av et lysbilde som er tilpasset en papirstørrelse</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0406"><label for="0406">Effekter</label><ul>\
    <li><a target="_top" href="nb/text/simpress/guide/animated_gif_save.html">Eksportere animasjoner i GIF-format</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/animated_objects.html">Animér objekter i lysbildepresentasjoner</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/animated_slidechange.html">Animerering av lysbildeoverganger</a></li>\
    <li><a target="_top" href="nb/text/sdraw/guide/cross_fading.html">Overgangstoning mellom to objekter</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/animated_gif_create.html">Opprette animerte GIF-bilder</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0407"><label for="0407">Objekter, grafikk og punktbilder</label><ul>\
    <li><a target="_top" href="nb/text/sdraw/guide/combine_etc.html">Slå sammen objekter og lage former</a></li>\
    <li><a target="_top" href="nb/text/sdraw/guide/draw_sector.html">Tegne sektorer og segmenter</a></li>\
    <li><a target="_top" href="nb/text/sdraw/guide/duplicate_object.html">Lag kopier av objekter</a></li>\
    <li><a target="_top" href="nb/text/sdraw/guide/rotate_object.html">Rotere objekter</a></li>\
    <li><a target="_top" href="nb/text/sdraw/guide/join_objects3d.html">Slå sammen 3D-objekter</a></li>\
    <li><a target="_top" href="nb/text/sdraw/guide/join_objects.html">Koble sammen linjer</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/text2curve.html">Omgjøring av teksttegn til tegneobjekter</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/vectorize.html">Omgjøring av bilder til vektorgrafikk</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/3d_create.html">Omgjøring av 2D-objekter til kurver, mangekanter og 3D-objekter</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/line_arrow_styles.html">Henting av linje- og pilstiler</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/line_draw.html">Tegning av kurver</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/line_edit.html">Redigering av kurver</a></li>\
    <li><a target="_top" href="nb/text/sdraw/guide/graphic_insert.html">Sette inn bilder</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/table_insert.html">Sette inn regneark i lysbilder</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/move_object.html">Flytting av objekter</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/select_object.html">Merking av underliggende objekter</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/orgchart.html">Opprettelse av et flytdiagram</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0408"><label for="0408">Grupper og lag</label><ul>\
    <li><a target="_top" href="nb/text/sdraw/guide/groups.html">Gruppere objekter</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/layers.html">Om lag</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/layer_new.html">Sette inn lag</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/layer_tipps.html">Arbeide med lag</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/layer_move.html">Flytting av objekter til et annet lag</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0409"><label for="0409">Tekst i presentasjoner og tegninger</label><ul>\
    <li><a target="_top" href="nb/text/sdraw/guide/text_enter.html">Legge til tekst</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/text2curve.html">Omgjøring av teksttegn til tegneobjekter</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0410"><label for="0410">Visning</label><ul>\
    <li><a target="_top" href="nb/text/simpress/guide/arrange_slides.html">Endring av lysbilderekkefølge</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/change_scale.html">Forstørrelse med tastaturet</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0411"><label for="0411">Lysbildeshow</label><ul>\
    <li><a target="_top" href="nb/text/simpress/guide/show.html">Vise en lysbildeframvisning</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/presenter_console.html">Bruk Presentasjonskonsollen </a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/impress_remote.html">Veivisning for Impress Remote</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/individual.html">Opprettelse av en tilpasset lysbildepresentasjon</a></li>\
    <li><a target="_top" href="nb/text/simpress/guide/rehearse_timings.html">Øv på tidsbruk og lysbildeskift</a></li>\
         </ul></li>\
     </ul></li></ul>\
    <ul><li><input type="checkbox" id="03"><label for="03">Formler</label><ul>\
    <li><input type="checkbox" id="0301"><label for="0301">Generell informasjon og bruk av brukergrensesnittet</label><ul>\
    <li><a target="_top" href="nb/text/smath/main0000.html">Velkommen til hjelp for LibreOffice Math</a></li>\
    <li><a target="_top" href="nb/text/smath/main0503.html">Funksjoner i LibreOffice Math</a></li>\
    <li><a target="_top" href="nb/text/smath/guide/main.html">Hjelp til bruk av LibreOffice Math</a></li>\
    <li><a target="_top" href="nb/text/smath/guide/keyboard.html">Hurtigtaster (LibreOffice Math-tilgjengelighet)</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0302"><label for="0302">Kommando og menyreferanse</label><ul>\
    <li><a target="_top" href="nb/text/smath/main0100.html">Menyer</a></li>\
    <li><a target="_top" href="nb/text/smath/main0200.html">Verktøylinjer</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0303"><label for="0303">Arbeid med formler</label><ul>\
    <li><a target="_top" href="nb/text/smath/guide/align.html">Justere formeldeler manuelt</a></li>\
    <li><a target="_top" href="nb/text/smath/guide/attributes.html">Endre standardegenskaper</a></li>\
    <li><a target="_top" href="nb/text/smath/guide/brackets.html">Slå sammen formeldeler i parenteser</a></li>\
    <li><a target="_top" href="nb/text/smath/guide/comment.html">Skrive inn merknader</a></li>\
    <li><a target="_top" href="nb/text/smath/guide/newline.html">Sette inn linjeskift</a></li>\
    <li><a target="_top" href="nb/text/smath/guide/parentheses.html">Sette inn parenteser</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="02"><label for="02">Tekstdokumenter</label><ul>\
    <li><input type="checkbox" id="0201"><label for="0201">Generell informasjon og bruk av brukergrensesnittet</label><ul>\
    <li><a target="_top" href="nb/text/swriter/main0000.html">Velkommen til hjelp for LibreOffice Writer</a></li>\
    <li><a target="_top" href="nb/text/swriter/main0503.html">Funksjoner i LibreOffice Writer</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/main.html">Veiledning for bruk av LibreOffice Writer</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/resize_navigator.html">Feste og endre størrelse på vinduer</a></li>\
    <li><a target="_top" href="nb/text/swriter/04/01020000.html">Hurtigtaster i LibreOffice Writer</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/words_count.html">Telle ord</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/keyboard.html">Bruke hurtigtaster (LibreOffice Writer-tilgjengelighet)</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0202"><label for="0202">Kommando og menyreferanse</label><ul>\
    <li><input type="checkbox" id="020201"><label for="020201">Menyer</label><ul>\
    <li><a target="_top" href="nb/text/swriter/main0100.html">Menyer</a></li>\
    <li><a target="_top" href="nb/text/swriter/main0101.html">Fil</a></li>\
    <li><a target="_top" href="nb/text/swriter/main0102.html">Rediger</a></li>\
    <li><a target="_top" href="nb/text/swriter/main0103.html">Vis</a></li>\
    <li><a target="_top" href="nb/text/swriter/main0104.html">Sett inn</a></li>\
    <li><a target="_top" href="nb/text/swriter/main0105.html">Format</a></li>\
    <li><a target="_top" href="nb/text/swriter/main0115.html">Stiler</a></li>\
    <li><a target="_top" href="nb/text/swriter/main0110.html">Tabell</a></li>\
    <li><a target="_top" href="nb/text/swriter/main0120.html">Skjemameny</a></li>\
    <li><a target="_top" href="nb/text/swriter/main0106.html">Verktøy</a></li>\
    <li><a target="_top" href="nb/text/swriter/main0107.html">Vindu</a></li>\
    <li><a target="_top" href="nb/text/shared/main0108.html">Hjelp</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="020202"><label for="020202">Verktøylinjer</label><ul>\
    <li><a target="_top" href="nb/text/swriter/main0200.html">Verktøylinjer</a></li>\
    <li><a target="_top" href="nb/text/swriter/main0202.html">Formateringslinja</a></li>\
    <li><a target="_top" href="nb/text/swriter/main0203.html">Bildelinje</a></li>\
    <li><a target="_top" href="nb/text/swriter/main0204.html">Verktøylinja «Tabell»</a></li>\
    <li><a target="_top" href="nb/text/swriter/main0205.html">Verktøylinja «Egenskaper for tegneobjekter»</a></li>\
    <li><a target="_top" href="nb/text/swriter/main0206.html">Verktøylinja Punkter og nummerering</a></li>\
    <li><a target="_top" href="nb/text/swriter/main0208.html">Statuslinja</a></li>\
    <li><a target="_top" href="nb/text/swriter/main0210.html">Forhåndsvisning av utskrift</a></li>\
    <li><a target="_top" href="nb/text/swriter/main0213.html">Linjaler</a></li>\
    <li><a target="_top" href="nb/text/swriter/main0214.html">Formellinja</a></li>\
    <li><a target="_top" href="nb/text/swriter/main0215.html">Rammelinja</a></li>\
    <li><a target="_top" href="nb/text/swriter/main0216.html">OLE-objektlinje</a></li>\
    <li><a target="_top" href="nb/text/swriter/main0220.html">Tekstobjektlinja</a></li>\
    <li><a target="_top" href="nb/text/shared/main0201.html">Standardlinja</a></li>\
    <li><a target="_top" href="nb/text/shared/main0212.html">Tabelldatalinja</a></li>\
    <li><a target="_top" href="nb/text/shared/main0213.html">Navigasjonslinje for skjema</a></li>\
    <li><a target="_top" href="nb/text/shared/main0214.html">Verktøylinje for spørringsutforming</a></li>\
    <li><a target="_top" href="nb/text/shared/main0226.html">Verktøylinje for skjemautforming</a></li>\
    <li><a target="_top" href="nb/text/swriter/librelogo/LibreLogo.html">Verktøylinja LibreLogo</a></li>\
			</ul></li>\
		</ul></li>\
    <li><input type="checkbox" id="0203"><label for="0203">Opprette tekstdokumenter</label><ul>\
    <li><a target="_top" href="nb/text/swriter/guide/text_nav_keyb.html">Navigering og valg ved bruk av tastaturet</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/text_direct_cursor.html">Bruke direkte skrivemerke</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0204"><label for="0204">Grafikk i tekstdokumenter</label><ul>\
    <li><a target="_top" href="nb/text/swriter/guide/insert_graphic.html">Sette inn bilder</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/insert_graphic_dialog.html">Sette inn et bilde fra en fil</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/insert_graphic_gallery.html">Sette inn bilder fra galleriet med dra og slipp</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/insert_graphic_scan.html">Sette inn et skannet bilde</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/insert_graphic_fromchart.html">Sette inn et Calc-diagram i et tekstdokument</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/insert_graphic_fromdraw.html">Sette inn bilder fra LibreOffice Draw eller Impress</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0205"><label for="0205">Tabeller i tekstdokumenter</label><ul>\
    <li><a target="_top" href="nb/text/swriter/guide/number_date_conv.html">Slå tallgjenkjenning i tabeller på eller av</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/tablemode.html">Endre rader og kolonner ved bruk av tastaturet</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/table_delete.html">Slette tabeller eller innholdet i en tabell</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/table_insert.html">Sette inn tabeller</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/table_repeat_multiple_headers.html">Gjenta en tabelloverskrift på en ny side</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/table_sizing.html">Endre størrelsen på rader og kolonner i en teksttabell</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/table_cells.html">Legge til eller slette en rad eller en kolonne i en tabell ved bruk av tastaturet</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0206"><label for="0206">Objekter i tekstdokumenter</label><ul>\
    <li><a target="_top" href="nb/text/swriter/guide/anchor_object.html">Plassere objekter</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/wrap.html">Tekstbryting rundt objekt</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0207"><label for="0207">Bolker og rammer i tekstdokumenter</label><ul>\
    <li><a target="_top" href="nb/text/swriter/guide/sections.html">Bruke bolker</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/text_frame.html">Innsetting, redigering og lenking av tekstrammer</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/section_edit.html">Redigering av bolker</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/section_insert.html">Sette inn bolker</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0208"><label for="0208">Innholdsliste og registre</label><ul>\
    <li><a target="_top" href="nb/text/swriter/guide/chapter_numbering.html">Kapittelnummerering</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/indices_userdef.html">Selvvalgte registere</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/indices_toc.html">Lage en innholdsliste</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/indices_index.html">Lage alfabetiske registere</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/indices_multidoc.html">Registere som dekker flere dokument</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/indices_literature.html">Lage en litteraturliste</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/indices_delete.html">Redigere og slette register- og tabelloppføringer</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/indices_edit.html">Oppdatere, redigere og slette registre og innholdslister</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/indices_enter.html">Angi oppføringer i indekser eller innholdslister</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/indices_form.html">Formatere et register eller en innholdsliste</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0209"><label for="0209">Felter i tekstdokumenter</label><ul>\
    <li><a target="_top" href="nb/text/swriter/guide/fields.html">Om felt</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/fields_date.html">Sette inn et fast eller variabelt datofelt</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/field_convert.html">Gjøre et felt om til tekst</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0210"><label for="0210">Navigasjon i tekstdokumenter</label><ul>\
    <li><a target="_top" href="nb/text/swriter/guide/dragdroptext.html">Flytte og kopiere tekst i dokumenter</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/arrange_chapters.html">Omorganisere et dokument ved å bruke «Dokumentstruktur»</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/hyperlinks.html">Sette inn hyperlenker med Dokumentstruktur</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/navigator.html">Dokumentstruktur i tekstdokument</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0211"><label for="0211">Beregning i tekstdokumenter</label><ul>\
    <li><a target="_top" href="nb/text/swriter/guide/calculate_multitable.html">Utregning på tvers av tabeller</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/calculate.html">Regning i tekstdokumenter</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/calculate_clipboard.html">Regne ut og lime inn resultatet av en formel i et tekstdokument</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/calculate_intable.html">Beregne totalsummer for celler i tabeller</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/calculate_intext.html">Regne ut avanserte formler i tekstdokumenter</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/calculate_intext2.html">Vise resultatet av en tabellutregning i en annen tabell</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0212"><label for="0212">Formatering av tekstdokumenter</label><ul>\
    <li><input type="checkbox" id="021201"><label for="021201">Maler og stiler</label><ul>\
    <li><a target="_top" href="nb/text/swriter/guide/templates_styles.html">Maler og stiler</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/even_odd_sdw.html">Ulike sidestiler på par- og oddetallssider</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/change_header.html">Lage en sidestil basert på den gjeldende siden</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/load_styles.html">Bruke stiler fra et annet dokument eller en mal</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/stylist_fromselect.html">Lage ny stiler fra utvalg</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/stylist_update.html">Oppdatere stiler fra utvalg</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/template_create.html">Lage en dokumentmal</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/template_default.html">Endre standardmalen</a></li>\
			</ul></li>\
    <li><a target="_top" href="nb/text/swriter/guide/pageorientation.html">Forandre sideretning (liggende eller stående)</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/text_capital.html">Endre skriftstørrelse i en tekst</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/hidden_text.html">Skjule tekst</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/header_pagestyles.html">Lage ulike topp- og bunntekster</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/header_with_chapter.html">Sette inn kapittelnavn og -nummer i en topp- eller bunntekst</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/shortcut_writing.html">Legge til tekstformatering mens du skriver</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/reset_format.html">Nullstilling av skriftegenskaper</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/stylist_fillformat.html">Legge til stiler i fyllformattilstand</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/wrap.html">Tekstbryting rundt objekt</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/text_centervert.html">Bruke en ramme for å midtstille tekst på en side</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/text_emphasize.html">Framhevelse av tekst</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/text_rotate.html">Rotering av tekst</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/page_break.html">Sette inn og slette sideskift</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/pagestyles.html">Lage og legge til sidestiler</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/subscript.html">Lage hevet eller senket skrift</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0213"><label for="0213">Spesielle tekstelementer</label><ul>\
    <li><a target="_top" href="nb/text/swriter/guide/captions.html">Bruke forklaringer</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/conditional_text.html">Vilkårstekst</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/conditional_text2.html">Vilkårstekst for sidetelling</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/fields_date.html">Sette inn et fast eller variabelt datofelt</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/fields_enter.html">Legge til innlister</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/footer_nextpage.html">Sette inn sidetall til kommende sider</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/footer_pagenumber.html">Sette inn sidetall i bunntekster</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/hidden_text.html">Skjule tekst</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/header_pagestyles.html">Lage ulike topp- og bunntekster</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/header_with_chapter.html">Sette inn kapittelnavn og -nummer i en topp- eller bunntekst</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/fields_userdata.html">Spørre etter brukerdata i felt eller vilkår</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/footnote_usage.html">Sette inn/redigere fotnoter og sluttnoter</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/footnote_with_line.html">Avstand mellom fotnoter</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/header_footer.html">Om topp- og bunntekster</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/header_with_line.html">Formatere topp- og bunntekster</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/text_animation.html">Animere tekst</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/form_letters_main.html">Lage et flettet brev</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0214"><label for="0214">Automatiske funksjoner</label><ul>\
    <li><a target="_top" href="nb/text/swriter/guide/autocorr_except.html">Legge til unntak i lista over autorettinger</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/autotext.html">Bruke autotekst</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/auto_numbering.html">Lag nummer- og punktlister mens du skriver</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/auto_off.html">Slå av Autoretting</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/auto_spellcheck.html">Automatisk stavekontroll</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/number_date_conv.html">Slå tallgjenkjenning i tabeller på eller av</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/using_hyphen.html">Orddeling</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0215"><label for="0215">Nummerering og lister</label><ul>\
    <li><a target="_top" href="nb/text/swriter/guide/captions_numbers.html">Legge til kapittelnumre i forklaringer</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/auto_numbering.html">Lag nummer- og punktlister mens du skriver</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/chapter_numbering.html">Kapittelnummerering</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/insert_tab_innumbering.html">Endre disposisjonsnivå i nummererte- og punktlister</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/join_numbered_lists.html">Slå sammen nummererte lister</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/numbering_lines.html">Legge til linjenumre</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/numbering_paras.html">Redigere nummerering i en nummerert liste</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/number_sequence.html">Angi tallområder</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/using_numbered_lists2.html">Legge til nummerering</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/using_numbering.html">Nummerering og nummereringsstiler</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/using_numbered_lists.html">Legge til punkttegn</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0216"><label for="0216">Stavekontroll, synonymordbok og språk</label><ul>\
    <li><a target="_top" href="nb/text/swriter/guide/auto_spellcheck.html">Automatisk stavekontroll</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/delete_from_dict.html">Fjerne ord fra egne ordlister</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/using_thesaurus.html">Synonymordliste</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/spellcheck_dialog.html">Kontrollere staving og grammatikk</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0218"><label for="0218">Feilsøking</label><ul>\
    <li><a target="_top" href="nb/text/swriter/guide/insert_beforetable.html">Sette inn tekst før en tabell øverst på en side</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/jump2statusbar.html">Gå til et spesielt bokmerke</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0219"><label for="0219">Åpne, lagre, import og eksport</label><ul>\
    <li><a target="_top" href="nb/text/swriter/guide/send2html.html">Lagre tekstdokumenter i HTML-format</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/textdoc_inframe.html">Sette inn et helt tekstdokument</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0220"><label for="0220">Hoveddokumenter</label><ul>\
    <li><a target="_top" href="nb/text/swriter/guide/globaldoc.html">Hoveddokument og underdokument</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0221"><label for="0221">Lenker og referanser</label><ul>\
    <li><a target="_top" href="nb/text/swriter/guide/references.html">Sette inn kryssreferanser</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/hyperlinks.html">Sette inn hyperlenker med Dokumentstruktur</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0222"><label for="0222">Utskrift</label><ul>\
    <li><a target="_top" href="nb/text/swriter/guide/printer_tray.html">Valg av skriverskuffer</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/print_preview.html">Forhåndsvise en side før utskrift</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/print_small.html">Skrive ut flere sider på et ark</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/pagestyles.html">Lage og legge til sidestiler</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0223"><label for="0223">Søk og erstatt</label><ul>\
    <li><a target="_top" href="nb/text/swriter/guide/search_regexp.html">Bruk av jokertegn i tekstsøk</a></li>\
    <li><a target="_top" href="nb/text/shared/01/02100001.html">Liste over regulære uttrykk</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="06"><label for="06">HTML-dokumenter</label><ul>\
    <li><a target="_top" href="nb/text/shared/07/09000000.html">Nettsider</a></li>\
    <li><a target="_top" href="nb/text/shared/02/01170700.html">HTML-filter og skjema</a></li>\
    <li><a target="_top" href="nb/text/swriter/guide/send2html.html">Lagre tekstdokumenter i HTML-format</a></li>\
	</ul></li></ul>\
';
